quantizationtools.WeightedSearchTree
====================================

.. abjad-lineage:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree

.. autoclass:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.all_compositions
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.default_definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__setstate__
   :noindex:
